@@ -15,13 +15,13 @@ fit <- survfit(Surv(time,status)~rx, data=colon)
 jskm(fit)
 jskm(fit, table = T, pval = T, label.nrisk = "No. at risk", size.label.nrisk = 8, 
      xlabs = "Time(Day)", ylabs = "Survival", ystratalabs = c("Obs", "Lev", "Lev + 5FU"), ystrataname = "rx",
-     marks = F, timeby = 365, xlims = c(0, 3000), ylims = c(0.25, 1))
+     marks = F, timeby = 365, xlims = c(0, 3000), ylims = c(0.25, 1), showpercent = T)
 
 ## -----------------------------------------------------------------------------
-jskm(fit, ci = T, cumhaz = T,  mark = F, ylab = "Cumulative hazard (%)", surv.scale = "percent", pval =T, pval.size = 6, pval.coord = c(300, 0.7))
+jskm(fit, ci = T, cumhaz = T,  mark = F, ylab = "Cumulative incidence (%)", surv.scale = "percent", pval =T, pval.size = 6, pval.coord = c(300, 0.7))
 
 ## -----------------------------------------------------------------------------
-jskm(fit, mark = F,  surv.scale = "percent", pval =T, table = T, cut.landmark = 500)
+jskm(fit, mark = F,  surv.scale = "percent", pval =T, table = T, cut.landmark = 500, showpercent = T)
 
 ## -----------------------------------------------------------------------------
 library(survey)
@@ -37,11 +37,11 @@ s2 <-svykm(Surv(time,status>0) ~ sex, design = dpbc)
 
 svyjskm(s1)
 svyjskm(s2)
-svyjskm(s2, cumhaz = T, ylab = "Cumulative hazard(%)", surv.scale = "percent") 
+svyjskm(s2, cumhaz = T, ylab = "Cumulative incidence(%)", surv.scale = "percent", showpercent = T) 
 
 ## -----------------------------------------------------------------------------
 s3 <- svykm(Surv(time,status>0) ~ sex, design=dpbc, se = T)
 svyjskm(s3)
-svyjskm(s3, ci = F)
+svyjskm(s3, ci = F, showpercent = T)
 svyjskm(s3, ci = F,  surv.scale = "percent", pval = T, table = T, cut.landmark = 1000)
 
